[CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout: - c2h/ (27 files): Catch2 test helpers — generators, validators, runner - nvbench_helper/ (10 files): Benchmark harness utilities - cmake/ (29 files): CMake presets and build helpers - cudax/ (794 files): Experimental CUDA extensions - AGENTS.md: NVIDIA's official AI agent instructions for CCCL - CMakePresets.json: Standardized build configurations - cccl-version.json: Version tracking Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to competition value and PRD items. cccl_upstream now covers 100% of competition-critical assets: - 27 tuning headers (SM80/90/100 benchmark data) - 32 dispatch headers (algorithm implementations) - 60 Thrust examples (correctness verification) - 217 CUB Catch2 tests (regression matrix) - 153 CUB benchmarks (parameter space search) - 18 CUB examples (API verification) - 27 test helpers + benchmark harness - 794 cudax experimental extensions
This commit is contained in:
69
cccl_upstream/cudax/test/stf/hash/ctx_hash.cu
Normal file
69
cccl_upstream/cudax/test/stf/hash/ctx_hash.cu
Normal file
@@ -0,0 +1,69 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <typename S>
|
||||
__global__ void inc_kernel(S sA)
|
||||
{
|
||||
sA(threadIdx.x)++;
|
||||
}
|
||||
|
||||
template <typename S1, typename S2>
|
||||
__global__ void copy_kernel(S1 sA, S2 sB)
|
||||
{
|
||||
sB(threadIdx.x) = sA(threadIdx.x);
|
||||
}
|
||||
|
||||
template <typename Ctx>
|
||||
void run()
|
||||
{
|
||||
int A[10] = {0};
|
||||
int B[10] = {0};
|
||||
Ctx ctx;
|
||||
|
||||
auto lA = ctx.logical_data(A);
|
||||
auto lB = ctx.logical_data(B);
|
||||
|
||||
for (size_t k = 0; k < 10; k++)
|
||||
{
|
||||
// fprintf(stderr, "iter %zu - 0 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lA.rw())->*[](cudaStream_t stream, auto sA) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sA);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 1 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lA.read(), lB.rw())->*[](cudaStream_t stream, auto sA, auto sB) {
|
||||
copy_kernel<<<1, 10, 0, stream>>>(sA, sB);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 2 : ctx.hash %zu\n", k, ctx.hash());
|
||||
ctx.task(lB.rw())->*[](cudaStream_t stream, auto sB) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sB);
|
||||
};
|
||||
|
||||
// fprintf(stderr, "iter %zu - 3 : ctx.hash %zu\n", k, ctx.hash());
|
||||
}
|
||||
|
||||
ctx.host_launch(lA.read(), lB.read())->*[&](auto /*unused*/, auto /*unused*/) {
|
||||
// fprintf(stderr, "HOST END : ctx.hash %zu\n", ctx.hash());
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
run<stream_ctx>();
|
||||
run<graph_ctx>();
|
||||
}
|
||||
51
cccl_upstream/cudax/test/stf/hash/logical_data.cu
Normal file
51
cccl_upstream/cudax/test/stf/hash/logical_data.cu
Normal file
@@ -0,0 +1,51 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <typename S>
|
||||
__global__ void inc_kernel(S sA)
|
||||
{
|
||||
sA(threadIdx.x)++;
|
||||
}
|
||||
|
||||
template <typename Ctx>
|
||||
void run()
|
||||
{
|
||||
int A[10] = {0};
|
||||
stream_ctx ctx;
|
||||
|
||||
auto l = ctx.logical_data(A);
|
||||
|
||||
for (size_t k = 0; k < 10; k++)
|
||||
{
|
||||
// size_t h = l.hash();
|
||||
// fprintf(stderr, "iter %zu : logical data hash %zu ctx.hash %zu\n", k, h, ctx.hash());
|
||||
|
||||
ctx.task(l.rw())->*[](cudaStream_t stream, auto sA) {
|
||||
inc_kernel<<<1, 10, 0, stream>>>(sA);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.host_launch(l.read())->*[&](auto /*unused*/) {
|
||||
// fprintf(stderr, "HOST end : logical data hash %zu ctx.hash %zu\n", l.hash(), ctx.hash());
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
run<stream_ctx>();
|
||||
run<graph_ctx>();
|
||||
}
|
||||
Reference in New Issue
Block a user